library connectivity_alert_widget;

import 'dart:async';

import 'package:connectivity/connectivity.dart';
import 'package:flutter/material.dart';

typedef ConnectivityCallback = Function(ConnectivityResult);

///Widget that alert the user of the app if it has connectivity or not
class ConnectivityAlertWidget extends StatefulWidget {
  ConnectivityAlertWidget({
    @required this.onlineWidget,
    @required this.offlineWidget,
    this.onConnectivityResult,
  })  : assert(onlineWidget != null),
        assert(offlineWidget != null);

  ///User can provide his own widget to show in case of online status
  final Widget onlineWidget;

  ///User can provide his own widget to show in case of offline status
  final Widget offlineWidget;

  ///User receives a callback so he can executes what he wants when the connectivity
  ///changes
  final ConnectivityCallback onConnectivityResult;

  @override
  _ConnectivityAlertWidgetState createState() =>
      _ConnectivityAlertWidgetState();
}

class _ConnectivityAlertWidgetState extends State<ConnectivityAlertWidget> {
  bool isOnline;
  StreamSubscription<ConnectivityResult> _subscription;

  @override
  void initState() {
    isOnline = true;

    _subscription = Connectivity().onConnectivityChanged.listen((result) {
      widget.onConnectivityResult(result);
      setState(() {
        if (result == ConnectivityResult.none) {
          isOnline = false;
        } else {
          isOnline = true;
        }
      });
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return isOnline ? widget.onlineWidget : widget.offlineWidget;
  }

  @override
  void dispose() {
    _subscription.cancel();
    super.dispose();
  }
}
